@@ -279,6 +279,10 @@ class FitsViewerApp(QMainWindow, fitsViewerGui.Ui_MainWindow):
 # 		palSelectButton.setColor(QPalette.Button, QColor(Qt.yellow))
 # 		self.btnSelectDataFile.setAutoFillBackground(True)
 # 		self.btnSelectDataFile.setPalette(palSelectButton)
+
+		self.cbPauseParamUpdates.setChecked(False)
+		self.cbPauseParamUpdates.stateChanged.connect(
+			self.onPauseFitsParamsUpdatesChanged)
 		
 		self.model_fits_params_left = fitsParamsLeftColModel()
 		
@@ -436,6 +440,11 @@ class FitsViewerApp(QMainWindow, fitsViewerGui.Ui_MainWindow):
 # 		lutHistog.imageItem().setLevels(lutHistog_levels)
 # 		print "[AFTER] getLevels():", lutHistog.imageItem().getLevels()
 # 		# lutHistog.update()
+
+	def onPauseFitsParamsUpdatesChanged(self, state):
+
+		if self.data_pathnames:
+			self.loadDataFile()
 	
 	def keyPressEvent(self, keyEvent):
 		
@@ -621,7 +630,10 @@ class FitsViewerApp(QMainWindow, fitsViewerGui.Ui_MainWindow):
 			self.image_array = ccd_image.data
 			self.imv.invertY(False)		# Need to invert if image is not FITS
 			
-			self.updateFitsParameters(ccd_image)
+			if self.cbPauseParamUpdates.isChecked():
+				self.updateFitsParameters(None)
+			else:
+				self.updateFitsParameters(ccd_image)
 		
 		else:
 		
